# SPDX-FileCopyrightText: 2021-2024 Simon Bruder <simon@sbruder.de>
#
# SPDX-License-Identifier: AGPL-3.0-or-later

{ config, lib, pkgs, ... }:
{
  imports = [
    ./hardware-configuration.nix
    ../../modules
    ../../users/simon

    ./services/languagetool.nix
    ./services/media-backup.nix
    ./services/media.nix
    ./services/photoprism.nix
    ./services/torrent.nix
  ];

  sbruder = {
    wireguard.home.enable = true;
    nginx.hardening.enable = true;
    restic.system = {
      enable = true;
      qos = true;
      extraPaths = [
        "/data"
      ];
      extraExcludes = [
        "/data/cold/media/video"
        "/data/cold/misc"
        "/data/cold/torrent"
        "/data/hot/torrent"
        "/data/media/video"
        "/data/torrent"
      ];
    };
    unfree.allowSoftware = true;
  };

  services.nginx = {
    enable = true;
  };
  networking.firewall.allowedTCPPorts = [ 80 443 ];
  systemd.services.nginx.serviceConfig.SupplementaryGroups = lib.singleton "keys";

  services.syncthing.enable = true;

  services.udisks2.enable = true; # does not have gui, but often deals with removable storage

  networking.hostName = "fuuko";

  system.stateVersion = "20.09";
}
