# SPDX-FileCopyrightText: 2020-2024 Simon Bruder <simon@sbruder.de>
#
# SPDX-License-Identifier: AGPL-3.0-or-later

{ pkgs, ... }:

{
  imports = [
    ./hardware-configuration.nix
    ../../modules
    ../../users/simon
  ];

  sbruder = {
    games = {
      enable = true;
      performanceIndex = 8;
    };
    gui.enable = true;
    media-proxy.enable = true;
    mullvad.enable = true;
    restic.system = {
      enable = true;
      qos = true;
    };
    unfree.allowSoftware = true;
    wireguard.home.enable = true;
  };

  virtualisation.libvirtd = {
    enable = true;
    qemu.package = pkgs.qemu_kvm;
  };

  services.samba = {
    enable = true;
    securityType = "user";
    extraConfig = ''
      interfaces = 192.168.122.1
      bind interfaces only = yes
      map to guest = bad user
      load printers = no
      printing = bsd
      disable spoolss = yes
      usershare max shares = 0
      acl allow execute always = True

      server min protocol = NT1
      ntlm auth = ntlmv1-permitted
    '';
    shares = {
      qemu = {
        path = "/home/simon/.cache/vm-share";
        browseable = "yes";
        "read only" = "no";
        "guest ok" = "yes";
        "force user" = "simon";
      };
    };
  };
  networking.firewall.trustedInterfaces = [ "virbr0" ];
  systemd.services.samba-nmbd = {
    wants = [ "libvirtd.service" ];
    after = [ "libvirtd.service" ];
  };

  services.tor = {
    enable = true;
    client.enable = true;
  };
  services.privoxy = {
    enable = true;
    enableTor = true;
  };

  networking.hostName = "mayushii";

  system.stateVersion = "21.05";

  boot.binfmt.emulatedSystems = [ "aarch64-linux" ];
}
