# SPDX-FileCopyrightText: 2021-2023 Simon Bruder <simon@sbruder.de>
#
# SPDX-License-Identifier: AGPL-3.0-or-later

{ config, lib, modulesPath, pkgs, ... }:
let
  bluetoothSupport = config.sbruder.full;
in
lib.mkIf config.sbruder.gui.enable {
  sound.enable = true;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;

    pulse.enable = true;
    alsa = {
      enable = true;
      support32Bit = true;
    };
    jack.enable = true;
  };

  environment.systemPackages = with pkgs; [
    unstable.helvum # patch panel
    pavucontrol
    pulseaudio # pacmd and pactl
    alsa-scarlett-gui # focusrite scarlett control
  ];

  hardware.bluetooth.enable = lib.mkDefault bluetoothSupport;
  services.blueman.enable = lib.mkDefault bluetoothSupport;

  boot.extraModprobeConfig = ''
    # Focusrite Scarlett Solo Gen 3 Mixer Driver
    options snd_usb_audio vid=0x1235 pid=0x8211 device_setup=1
  '';
}
