# SPDX-FileCopyrightText: 2018-2021 Simon Bruder <simon@sbruder.de>
#
# SPDX-License-Identifier: AGPL-3.0-or-later

{ lib, nixosConfig, ... }:

lib.mkIf nixosConfig.sbruder.gui.enable {
  home.file.".XCompose".text = ''
    include "%L"

    # units
    <Multi_key> <l> <l>                 : "ℓ"   U2113         # litre symbol
    <Multi_key> <u> <space>             : " "   U202F         # NARROW NO-BREAK SPACE
    <Multi_key> <z> <space>             : "​"   U200B         # ZERO WIDTH SPACE

    # maths
    <Multi_key> <p> <i>                 : "π"   U03C0         # GREEK SMALL LETTER PI
    <Multi_key> <exclam> <equal>        : "≠"   U2260         # NOT EQUAL TO
    <Multi_key> <slash> <equal>         : "≠"   U2260         # NOT EQUAL TO
    <Multi_key> <asciitilde> <equal>    : "≈"   U2248         # ALMOST EQUAL TO
    <Multi_key> <i> <n>                 : "∈"   U2208         # ELEMENT OF
    <Multi_key> <s> <q>                 : "√"   U221A         # SQUARE ROOT
    <Multi_key> <d> <e>                 : "Δ"   U0394         # GREEK CAPITAL LETTER DELTA

    <Multi_key> <bar> <C>               : "ℂ"   U2102         # DOUBLE-STRUCK CAPITAL C (set of complex numbers)
    <Multi_key> <bar> <N>               : "ℕ"   U2115         # DOUBLE-STRUCK CAPITAL N (natural number)
    <Multi_key> <bar> <P>               : "ℙ"   U2119         # DOUBLE-STRUCK CAPITAL P
    <Multi_key> <bar> <Q>               : "ℚ"   U211A         # DOUBLE-STRUCK CAPITAL Q (set of rational numbers)
    <Multi_key> <bar> <R>               : "ℝ"   U211D         # DOUBLE-STRUCK CAPITAL R (set of real numbers)
    <Multi_key> <bar> <Z>               : "ℤ"   U2124         # DOUBLE-STRUCK CAPITAL Z (set of integers)
    <Multi_key> <L> <L>                 : "𝕃"   U1D543        # DOUBLE-STRUCK CAPITAL L
    <Multi_key> <bar> <O>               : "Ω"   U03A9         # Greek Capital Letter Omega

    # right typography
    ## english
    <Multi_key> <space> <minus>         : " — "               # EM DASH surrounded by THIN SPACEs.

    ## roman numerals
    ### small
    <Multi_key> <percent> <1>               : "ⅰ"   U2170           # SMALL ROMAN NUMERAL ONE
    <Multi_key> <percent> <2>               : "ⅱ"   U2171           # SMALL ROMAN NUMERAL TWO
    <Multi_key> <percent> <3>               : "ⅲ"   U2172           # SMALL ROMAN NUMERAL THREE
    <Multi_key> <percent> <4>               : "ⅳ"   U2173           # SMALL ROMAN NUMERAL FOUR
    <Multi_key> <percent> <5>               : "ⅴ"   U2174           # SMALL ROMAN NUMERAL FIVE
    <Multi_key> <percent> <6>               : "ⅵ"   U2175           # SMALL ROMAN NUMERAL SIX
    <Multi_key> <percent> <7>               : "ⅶ"   U2176           # SMALL ROMAN NUMERAL SEVEN
    <Multi_key> <percent> <8>               : "ⅷ"   U2177           # SMALL ROMAN NUMERAL EIGHT
    <Multi_key> <percent> <9>               : "ⅸ"   U2178           # SMALL ROMAN NUMERAL NINE
    <Multi_key> <percent> <x>               : "ⅹ"   U2179           # SMALL ROMAN NUMERAL TEN
    <Multi_key> <percent> <underscore> <1>  : "ⅺ"   U217A           # SMALL ROMAN NUMERAL ELEVEN
    <Multi_key> <percent> <underscore> <2>  : "ⅻ"   U217B           # SMALL ROMAN NUMERAL TWELVE
    <Multi_key> <percent> <l>               : "ⅼ"   U217C           # SMALL ROMAN NUMERAL FIFTY
    <Multi_key> <percent> <c>               : "ⅽ"   U217D           # SMALL ROMAN NUMERAL ONE HUNDRED
    <Multi_key> <percent> <d>               : "ⅾ"   U217E           # SMALL ROMAN NUMERAL FIVE HUNDRED
    <Multi_key> <percent> <m>               : "ⅿ"   U217F           # SMALL ROMAN NUMERAL ONE THOUSAND

    ### capital
    <Multi_key> <percent> <0> <1>               : "Ⅰ"   U2160       # ROMAN NUMERAL ONE
    <Multi_key> <percent> <0> <2>               : "Ⅱ"   U2161       # ROMAN NUMERAL TWO
    <Multi_key> <percent> <0> <3>               : "Ⅲ"   U2162       # ROMAN NUMERAL THREE
    <Multi_key> <percent> <0> <4>               : "Ⅳ"   U2163       # ROMAN NUMERAL FOUR
    <Multi_key> <percent> <0> <5>               : "Ⅴ"   U2164       # ROMAN NUMERAL FIVE
    <Multi_key> <percent> <0> <6>               : "Ⅵ"   U2165       # ROMAN NUMERAL SIX
    <Multi_key> <percent> <0> <7>               : "Ⅶ"   U2166       # ROMAN NUMERAL SEVEN
    <Multi_key> <percent> <0> <8>               : "Ⅷ"   U2167       # ROMAN NUMERAL EIGHT
    <Multi_key> <percent> <0> <9>               : "Ⅸ"   U2168       # ROMAN NUMERAL NINE
    <Multi_key> <percent> <0> <x>               : "Ⅹ"   U2169       # ROMAN NUMERAL TEN
    <Multi_key> <percent> <underscore> <0> <1>  : "Ⅺ"   U216A       # ROMAN NUMERAL ELEVEN
    <Multi_key> <percent> <underscore> <0> <2>  : "Ⅻ"   U216B       # ROMAN NUMERAL TWELVE
    <Multi_key> <percent> <0> <l>               : "Ⅼ"   U216C       # ROMAN NUMERAL FIFTY
    <Multi_key> <percent> <0> <c>               : "Ⅽ"   U216D       # ROMAN NUMERAL ONE HUNDRED
    <Multi_key> <percent> <0> <d>               : "Ⅾ"   U216E       # ROMAN NUMERAL FIVE HUNDRED
    <Multi_key> <percent> <0> <m>               : "Ⅿ"   U216F       # ROMAN NUMERAL ONE THOUSAND
    <Multi_key> <percent> <X>                   : "Ⅹ"   U2169       # ROMAN NUMERAL TEN
    <Multi_key> <percent> <L>                   : "Ⅼ"   U216C       # ROMAN NUMERAL FIFTY
    <Multi_key> <percent> <C>                   : "Ⅽ"   U216D       # ROMAN NUMERAL ONE HUNDRED
    <Multi_key> <percent> <D>                   : "Ⅾ"   U216E       # ROMAN NUMERAL FIVE HUNDRED
    <Multi_key> <percent> <M>                   : "Ⅿ"   U216F       # ROMAN NUMERAL ONE THOUSAND
    <Multi_key> <percent> <0> <C> <D>           : "ↀ"   U2180       # ROMAN NUMERAL ONE THOUSAND C D
    <Multi_key> <percent> <0> <D>               : "ↁ"   U2181       # ROMAN NUMERAL FIVE THOUSAND
    <Multi_key> <percent> <0> <M>               : "ↂ"   U2182       # ROMAN NUMERAL TEN THOUSAND
    <Multi_key> <percent> <0> <0> <D>           : "ↇ"   U2187       # ROMAN NUMERAL FIFTY THOUSAND
    <Multi_key> <percent> <0> <0> <M>           : "ↈ"   U2188       # ROMAN NUMERAL ONE HUNDRED THOUSAND

    # symbols
    <Multi_key> <Left> <Left>           : "←"   leftarrow     # LEFTWARDS ARROW
    <Multi_key> <Up> <Up>               : "↑"   uparrow       # UPWARDS ARROW
    <Multi_key> <Right> <Right>         : "→"   rightarrow    # RIGHTWARDS ARROW
    <Multi_key> <Down> <Down>           : "↓"   downarrow     # DOWNWARDS ARROW

    <Multi_key> <o> <k>                 : "✓"   U2713         # CHECK MARK
    <Multi_key> <n> <o>                 : "❌"   U274F         # CROSS MARK
    <Multi_key> <t> <u>                 : "👍"   U1F44D        # THUMBS UP SIGN
  '';
}
